@@ -4,7 +4,7 @@
 {
 	#create arfinternal environment
 	.arfInternal = new.env(hash=T,parent=emptyenv())
-	assign('.arfInternal',.arfInternal,envir=.GlobalEnv)
+	.arfInternal <<- .arfInternal
 	
 }
 
